## About the Package:
The package was an assignment in a course I had taken about Machine Learning.

The package is about making the Gaussian, and the Binomial distribution easy to work with .
There's The Gaussian sub Module, and the Binomial sub Module as well.
## Features:
With The package , you can :
* Read from the dataset.
* calculate the mean for the Gaussian distribution, and the Binomial distribution as well.
* calculate the standard deviation .
* Plot the histogram of the data.
* Calculate the probability density function for the distribution.
* Plot the probability density function.
* Add two Gaussian Distributions .
* Add two Binomial Distributions (if only they have the same probability p, the complex case is not developed yet may be soon).
